# ProcessingOptions

The container for billing processing options and payment processing options.  **Note:** - This field is not supported in draft orders. - When you use the \"Create an order\" operation to create an account, create a subscription, run billing, and collect payment in a single call, if any error occurs during the call, such as a payment processing failure and a tax engine failure, then all the other steps will be rolled back. In this case, neither the invoice will be generated, nor the subscription nor the account will be created. - When you use the \"Create an order\" operation to cancel a subscription with `refund` and `writeOff`, if the `refund` or `writeOff` fails, `cancelSubscription`, `runBilling`, and `collectPayment` still can succeed. - When you use the \"Create an order\" operation, the `collectPayment` and `refund` fields cannot be set to `true` simultaneously.  Otherwise, the order will not be proceeded. 

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**application_order** | **List[str]** | The priority order to apply credit memos and/or unapplied payments to an invoice. Possible item values are: &#x60;CreditMemo&#x60;, &#x60;UnappliedPayment&#x60;.  **Note:**   - This field is valid only if the &#x60;applyCredit&#x60; field is set to &#x60;true&#x60;.   - If no value is specified for this field, the default priority order is used, [\&quot;CreditMemo\&quot;, \&quot;UnappliedPayment\&quot;], to apply credit memos first and then apply unapplied payments.   - If only one item is specified, only the items of the spedified type are applied to invoices. For example, if the value is &#x60;[\&quot;CreditMemo\&quot;]&#x60;, only credit memos are used to apply to invoices.  | [optional] 
**apply_credit** | **bool** | Whether to automatically apply credit memos or unapplied payments, or both to an invoice.  If the value is true, the credit memo or unapplied payment on the order account will be automatically applied to the invoices generated by this order. The credit memo generated by this order will not be automatically applied to any invoices.             **Note:** This field is only available if you have [Invoice Settlement](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement) enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information.  | [optional] 
**apply_credit_balance** | **bool** | Indicates if any credit balance on a customer&#39;s account is automatically applied to invoices. If no value is specified then this field defaults to false. This feature is not available if you have enabled the Invoice Settlement feature.  | [optional] 
**billing_options** | [**BillingOptions**](BillingOptions.md) |  | [optional] 
**collect_payment** | **bool** | Indicates if the current request needs to collect payments. This value can not be &#39;true&#39; when &#39;runBilling&#39; flag is &#39;false&#39;.  | [optional] 
**electronic_payment_options** | [**ElectronicPaymentOptions**](ElectronicPaymentOptions.md) |  | [optional] 
**refund** | **bool** | Indicates whether to refund after subscription cancelation. Default is &#x60;false&#x60;.   **Note**: When refunding a subscription that is not invoiced separately, if you do not enable the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Billing_and_Invoicing/Invoice_Settlement/C_Invoice_Item_Settlement\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Invoice Item Settlement&lt;/a&gt; feature, you will encounter the following error during the cancel and refund process: “Cancellation/Refund failed because of the following reason: Invoice is linked to multiple subscriptions. Cancellation was not processed.”  | [optional] 
**refund_amount** | **float** | Indicates the amount to be refunded. Required if the &#x60;refund&#x60; field is &#x60;true&#x60;.  | [optional] 
**refund_reason_code** | **str** | A code identifying the reason for the refund transaction. The value must be an existing payment refund reason code listed in **Payments Settings** &gt; **Configure Reason Codes**. If you do not specify the field or leave the field with an empty value, Zuora uses the default payment refund reason code.  | [optional] 
**run_billing** | **bool** | Indicates if the current request needs to generate an invoice. The invoice will be generated against all subscriptions included in this order.  | [optional] 
**write_off** | **bool** | Indicates whether to write off the outstanding balance on the invoice after refund. Default is &#x60;false&#x60;.  **Note**:  - When refunding a subscription that is not invoiced separately, if you do not enable the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Billing_and_Invoicing/Invoice_Settlement/C_Invoice_Item_Settlement\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Invoice Item Settlement&lt;/a&gt; feature, you will encounter the following error during the cancel and refund process: “Cancellation/Refund failed because of the following reason: Invoice is linked to multiple subscriptions. Cancellation was not processed.” - The &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Billing_and_Invoicing/Invoice_Settlement\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Invoice Settlement&lt;/a&gt; feature must have been enabled for write-off.  | [optional] 
**write_off_behavior** | [**WriteOffBehavior**](WriteOffBehavior.md) |  | [optional] 

## Example

```python
from zuora_sdk.models.processing_options import ProcessingOptions

# TODO update the JSON string below
json = "{}"
# create an instance of ProcessingOptions from a JSON string
processing_options_instance = ProcessingOptions.from_json(json)
# print the JSON string representation of the object
print(ProcessingOptions.to_json())

# convert the object into a dict
processing_options_dict = processing_options_instance.to_dict()
# create an instance of ProcessingOptions from a dict
processing_options_from_dict = ProcessingOptions.from_dict(processing_options_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


